@@ -11,21 +11,21 @@
          double precision,dimension(m*(m+3)/2),intent(out)::v
      double precision,dimension(2)::k0
          double precision,intent(out)::rl
-         double precision,dimension(m),intent(inout)::b    
+         double precision,dimension(m),intent(inout)::b
      double precision,intent(out)::ca,cb,dd
      external::fctnames
      double precision::fctnames
 
       end subroutine marq98j
 
-      subroutine derivaj(b,m,v,rl,k0,fctnames)
+      subroutine derivaJ(b,m,v,rl,k0,fctnames)
         integer,intent(in)::m
     double precision,dimension(2)::k0
         double precision,intent(inout)::rl
         double precision,dimension(m),intent(in)::b
         double precision,dimension((m*(m+3)/2)),intent(out)::v
     double precision,external::fctnames
-      end subroutine derivaj
+      end subroutine derivaJ
 
       subroutine searpasj(vw,step,b,bh,m,delta,fim,k0,fctnames)
         integer,intent(in)::m
@@ -39,7 +39,7 @@
       subroutine dmfsdj(a,n,eps,ier)
         integer,intent(in)::n
         integer,intent(inout)::ier
-        double precision,intent(inout)::eps 
+        double precision,intent(inout)::eps
         double precision,dimension(n*(n+1)/2),intent(inout)::A
       end subroutine dmfsdj
 
@@ -55,7 +55,7 @@
 
       subroutine dmaxt(maxt,delta,m)
         integer,intent(in)::m
-        double precision,dimension(m),intent(in)::delta 
+        double precision,dimension(m),intent(in)::delta
         double precision,intent(out)::maxt
       end subroutine dmaxt
       end interface verif1
@@ -88,7 +88,7 @@
       implicit none
 ! -Interface permettant la verification des type des arguments
       interface verif1
-        module procedure marq98j,derivaj,searpasj,dmfsdj,valfpaj
+        module procedure marq98j,derivaJ,searpasj,dmfsdj,valfpaj
       end interface verif1
 
       interface verif2
@@ -159,11 +159,11 @@
     m1=m*(m+1)/2
     ep=1.d-20
     Main:Do
-
-        call derivaj(b,m,v,rl,k0,fctnames)
-
-
+        !print*,"dans aaOptim, appel de derivaJ avec funcpa... "
+        call derivaJ(b,m,v,rl,k0,fctnames)
     rl1=rl
+    !print *,"rl1 = ", rl1
+
     if(rl.eq.-1.D9) then
         istop=4
         goto 110
@@ -174,16 +174,16 @@
         dd = 0.d0
 
         fu=0.D0
-    
+
     do i=1,m
         do j=i,m
             ij=(j-1)*j/2+i
             fu(ij)=v(ij)
         end do
     end do
-    
+
         call dsinvj(fu,m,ep,ier)
-    
+
     if (ier.eq.-1) then ! hessienne non inversible
         !print*,"here"
         dd=epsd+1.d0
@@ -221,7 +221,7 @@
             tr=tr+dabs(v(ii))
         end do
         tr=tr/dble(m)
-        
+
         ncount=0
         ga=0.01d0
 
@@ -237,7 +237,7 @@
                 fu(ii)=da*ga*tr
             endif
         end do
-        
+
         call dcholej(fu,m,nql,idpos)
 
         if (idpos.ne.0) then
@@ -256,8 +256,9 @@
                 delta(i)=fu(nfmax+i)
                 b1(i)=b(i)+delta(i)
             end do
-            
+
             rl=fctnames(b1,m,id,z,jd,z,k0)
+
             if(rl.eq.-1.D9) then
                 istop=4
                 goto 110
@@ -279,11 +280,13 @@
         else
             !call dmaxt(maxt,delta,m)
             vw=th/maxt
-            
+
         endif
         step=dlog(1.5d0)
 !      write(*,*) 'searpas'
+        !print*,"dans aaOptim, appel de searpasJ avec funcpa... "
         call searpasj(vw,step,b,bh,m,delta,fi,k0,fctnames)
+
         rl=-fi
         if(rl.eq.-1.D9) then
             istop=4
@@ -296,17 +299,19 @@
         da=(dm-3.d0)*da
 
  800     cb=dabs(rl1-rl)
- 
+
         ca=0.d0
         do i=1,m
             ca=ca+delta(i)*delta(i)
         end do
         !write(6,*) 'ca =',ca,' cb =',cb,' dd =',dd
 
+        !print*,"rl1=",rl1
+        !print*,"ca =",ca," cb =",cb," dd =",dd
         do i=1,m
             b(i)=b(i)+delta(i)
         end do
-        
+
         ni=ni+1
         if (ni.ge.maxiter) then
             istop=2
@@ -316,15 +321,16 @@
     End do Main
 
     v=0.D0
-    
+
     v(1:m*(m+1)/2)=fu(1:m*(m+1)/2)
-    
+
     istop=1
-    
+
 !================ pour les bandes de confiance
 !==== on ne retient que les para des splines
 
     call derivaJ(b,m,v,rl,k0,fctnames)
+     !print*,"dans aaOptim, appel de derivaJ  with GAP vec funcpa... "
     if(rl.eq.-1.D9) then
         istop=4
         goto 110
@@ -338,8 +344,12 @@
     select case(model)
         case(1)
             m1=m-nva-effet-indic_alpha !joint
+
+        !cas supplementaire rajout pour joint general
+        case(5)
+            m1=m-nva-effet-indic_alpha !joint general (du moment que indic_eta=indic_alpha=1)
         case(2)
-            m1=m-nva-effet*2 !additive    
+            m1=m-nva-effet*2 !additive
         case(3)
             m1=m-nva-effet !nested
         case(4)
@@ -347,7 +357,7 @@
     end select
 
     kkk=m1*(m1+1)/2
-    
+
     do i=1,m1
         kkk=kkk+1
         do j=i,m1
@@ -355,7 +365,7 @@
             v1(k)=v(k)/(4.d0*b(i)*b(j))
         end do
         v1(kkk)=v1(kkk)+(v(kkk)/(4.d0*b(i)*b(i)*b(i)))
-    end do 
+    end do
 
     ep=10.d-10
     call dsinvJ(v1,m1,ep,ier)
@@ -379,13 +389,13 @@
         end do
     end do
 
-    
+
     ep=10.d-10
     call dsinvJ(v,m,ep,ier)
-    
+
     if (ier.eq.-1) then
         istop=3
-        
+
 !AD:
 !        call dsinvj(v1,m1,ep,ier)
 !        if (ier.eq.-1) then
@@ -396,20 +406,20 @@
 !            DO k=1,m1*(m1+1)/2
 !                v(k)=v1(k)
 !            END DO
-!        end if    
+!        end if
 ! fin ajout amadou
     endif
 
 
     ep=10.d-10
     call derivaJ(b,m,vnonpen,rl,zero,fctnames)
-    
+
     do i=1,m
         do j=i,m
             I_hess(i,j)=vnonpen((j-1)*j/2+i)
         end do
     end do
-   
+
     do i=2,m
         do j=1,i-1
             I_hess(i,j)=I_hess(j,i)
@@ -430,7 +440,7 @@
         do j=1,i-1
             H_hess(i,j)=H_hess(j,i)
         end do
-    end do      
+    end do
 
  !AD:
     if (typeof .ne. 0) then
@@ -438,51 +448,40 @@
             vvv(i)=v(i)
         end do
     end if
-       
+
  110   continue
 
-       return    
+       return
        end subroutine marq98j
 
 !------------------------------------------------------------
 !                          DERIVA
 !------------------------------------------------------------
 
-    subroutine derivaj(b,m,v,rl,k0,fctnames)
+    subroutine derivaJ(b,m,v,rl,k0,fctnames)
     use comon,only:model,k0T,nst,nstRec
     implicit none
-    
+
     integer,intent(in)::m
     double precision,intent(inout)::rl
     double precision,dimension(2)::k0
     double precision,dimension(m),intent(in)::b
-    double precision,dimension((m*(m+3)/2)),intent(out)::v
+    double precision,dimension((m*(m+3)/2)),intent(inout)::v
     double precision,dimension(m)::fcith
     integer ::i0,m1,ll,i,k,j,iun
     double precision::fctnames,thn,th,z,vl,th2,vaux
     external::fctnames
+    logical::endDeriva
+
+    endDeriva=.false.
 
 
-    !en plus strates A.Lafourcade 05/2014
-!     if ((model.eq.1).or.(model.eq.4)) then
-!         if (nst==1) then
-!             k0T(1)=0.d0
-!             k0T(1)=k0(1)
-!         end if
-!         if (nst.ge.2) then
-!             if (nstRec==0) then !en plus que pour le modèle shared
-!                 k0T(1)=0.d0
-!                 k0T(1)=k0(1)
-!                 k0T(2)=0.d0
-!                 k0T(2)=k0(2)
-!             end if
-!         end if
-!     endif
-    !!!fin modif strates
 
     select case(model)
     case(1)
         th=1.d-3 !joint
+    case(5)
+        th=1.d-5 !joint general !cas supplementaire rajout
     case(2)
         th=5.d-3 !additive
     case(3)
@@ -497,46 +496,55 @@
     i0=0
     iun =1
 
+        !print *,"k0 = ",k0
+        !print *,"b = ", b
+        !size(b) =32 , m =32
+        !print *,"z = ", z            ! =0.000000000
+        !print *,"iun", iun           ! =1
+        !print *,"rl = ",rl           ! =0.000000000
+
 
     rl=fctnames(b,m,iun,z,iun,z,k0)
 
-
-    if(rl.eq.-1.d9) then
-        rl=-1.d9
-        goto 123
-    end if
-
-    do i=1,m
-        fcith(i)=fctnames(b,m,i,th,i0,z,k0)
-        if(fcith(i).eq.-1.d9) then
-            rl=-1.d9
-            goto 123
-        end if
-    end do
-
-    k=0
-    m1=m*(m+1)/2
-    ll=m1
-
-    do i=1,m
-        ll=ll+1
-        vaux=fctnames(b,m,i,thn,i0,z,k0)
-        if(vaux.eq.-1.d9) then
-            rl=-1.d9
-            goto 123
-        end if
-        vl=(fcith(i)-vaux)/(2.d0*th)
-        v(ll)=vl
-        do j=1,i
-            k=k+1
-            v(k)=-(fctnames(b,m,i,th,j,th,k0)-fcith(j)-fcith(i)+rl)/th2
+    if(rl.ne.-1.d9) then
+        do i=1,m
+            if((fcith(i).ne.-1.d9).and.(endDeriva.eqv..false.)) then
+                fcith(i)=fctnames(b,m,i,th,i0,z,k0)
+            else
+                rl=-1.d9
+                endDeriva=.true.
+            end if
         end do
-    end do
 
-123   continue    
+        if (endDeriva.eqv..false.) then
+            k=0
+            m1= (m*(m+1)/2)
+            !print*,"m1 =",m1
+            ll=m1
+
+            do i=1,m
+                !print*, "deuxieme boucle DERIVAj, tour",i," :"
+                ll=ll+1
+                vaux=fctnames(b,m,i,thn,i0,z,k0)
+                if(vaux.eq.-1.d9) then
+                    rl=-1.d9
+                    endDeriva=.true.
+                end if
+                if (endDeriva.eqv..false.) then
+                    vl=(fcith(i)-vaux)/(2.d0*th)
+                    v(ll)=vl
+                    !print*,"vl(",ll,") =",v(ll)
+                    do j=1,i
+                        k=k+1
+                        v(k)=-(fctnames(b,m,i,th,j,th,k0)-fcith(j)-fcith(i)+rl)/th2
+                    end do
+                end if
+            end do
+        end if
+    end if
     return
-    
-    end subroutine derivaj
+
+    end subroutine derivaJ
 !------------------------------------------------------------
 !                        SEARPAS
 !------------------------------------------------------------
@@ -574,7 +582,7 @@
           vlw1=vlw2+step
           call valfpaj(vlw1,fi1,b,bh,m,delta,k0,fctnames)
           if(fi1.gt.fi2) goto 50
-       else 
+       else
           vlw=vlw1
           vlw1=vlw2
           vlw2=vlw
@@ -594,7 +602,7 @@
           if(fi1.gt.fi2) goto 50
           if(fi1.eq.fi2) then
              fim=fi2
-             vm=vlw2 
+             vm=vlw2
              goto 100
           end if
        end do
@@ -605,14 +613,14 @@
 !
 !  CALCUL MINIMUM QUADRIQUE
 !
-      vm=vlw2-step*(fi1-fi3)/(2.d0*(fi1-2.d0*fi2+fi3))   
-      call valfpaj(vm,fim,b,bh,m,delta,k0,fctnames)    
+      vm=vlw2-step*(fi1-fi3)/(2.d0*(fi1-2.d0*fi2+fi3))
+      call valfpaj(vm,fim,b,bh,m,delta,k0,fctnames)
       if(fim.le.fi2) goto 100
       vm=vlw2
       fim=fi2
 100   continue
       vw=dexp(vm)
-      
+
       return
 
       end subroutine searpasj
@@ -624,18 +632,18 @@
       subroutine dcholej(a,k,nq,idpos)
 
       implicit none
-      
+
       integer,intent(in)::k,nq
       integer,intent(inout)::idpos
       double precision,dimension(k*(k+3)/2),intent(inout)::a
-        
+
       integer::i,ii,i1,i2,i3,m,j,k2,jmk
       integer::ijm,irm,jji,jjj,l,jj,iil,jjl,il
-      integer,dimension(k)::is    
+      integer,dimension(k)::is
       double precision ::term,xn,diag,p
       equivalence (term,xn)
-      
-       
+
+
 !      ss programme de resolution d'un systeme lineaire symetrique
 !
 !       k ordre du systeme /
@@ -650,7 +658,7 @@
       idpos=0
       k2=k+nq
 !     calcul des elements de la matrice
-      do i=1,k   
+      do i=1,k
          ii=i*(i+1)/2
 !       elements diagonaux
          diag=a(ii)
@@ -666,8 +674,8 @@
              if(is(l).ge.0) goto 3
 2            p=-p
 3            diag=diag-p
-         end do     
-         
+         end do
+
 4        if(diag.lt.0) goto 5
          if(diag.eq.0) goto 50
          if(diag.gt.0) goto 6
@@ -689,7 +697,7 @@
 8           jj=jj-jmk*(jmk+1)/2
 9           term=a(jj)
             if(i-1.ne.0) goto 10
-            if(i-1.eq.0) goto 13 
+            if(i-1.eq.0) goto 13
 10          do l=1,i2
                iil=ii-l
                jjl=jj-l
@@ -701,9 +709,9 @@
 12             term=term-p
             end do
 13            a(jj)=term/diag
-       end do  
-      end do   
-      
+       end do
+      end do
+
 !       calcul des solutions
       jj=ii-k+1
       do l=1,nq
@@ -750,10 +758,10 @@
 !   IER = K COMPRIS ENTRE 1 ET N, WARNING, LE CALCUL CONTINUE
 !
       implicit none
-      
+
       integer,intent(in)::n
       integer,intent(inout)::ier
-      double precision,intent(inout)::eps 
+      double precision,intent(inout)::eps
       double precision,dimension(n*(n+1)/2),intent(inout)::A
       double precision :: dpiv,dsum,tol
       integer::i,k,l,kpiv,ind,lend,lanf,lind
@@ -791,22 +799,22 @@
                lanf=kpiv-l
                lind=ind-l
            dsum=dsum+A(lanf)*A(lind)
-            end do 
-          
-!     
+            end do
+
+!
 !   END OF INNEF LOOP
 !
 !   TRANSFORM ELEMENT A(IND)
-!     
+!
 4           dsum=A(ind)-dsum
             if (i-k.ne.0) goto 10
             if (i-k.eq.0) goto 5
 !
 !   TEST FOR NEGATIVE PIVOT ELEMENT AND FOR LOSS OF SIGNIFICANCE
-!    
+!
 5           if (sngl(dsum)-tol.le.0) goto 6
             if (sngl(dsum)-tol.gt.0) goto 9
-6           if (dsum.le.0) goto 12  
+6           if (dsum.le.0) goto 12
             if (dsum.gt.0) goto 7
 7           if (ier.le.0) goto 8
             if (ier.gt.0) goto 9
@@ -825,7 +833,7 @@
 11          ind=ind+i
          end do
       end do
-      
+
 !
 !   END OF DIAGONAL-LOOP
 !
@@ -863,21 +871,21 @@
 !         IER=1 PERTE DE SIGNIFICANCE, LE CALCUL CONTINUE
 !
     implicit none
-    
+
     integer,intent(in)::n
     integer,intent(inout)::ier
-    double precision,intent(inout)::eps        
-    double precision,dimension(n*(n+1)/2),intent(inout)::A     
+    double precision,intent(inout)::eps
+    double precision,dimension(n*(n+1)/2),intent(inout)::A
     double precision::din,work
     integer::ind,ipiv,i,j,k,l,min,kend,lhor,lver,lanf
-    
+
 !
 !     FACTORIZE GIVEN MATRIX BY MEANS OF SUBROUTINE DMFSD
 !     A=TRANSPOSE(T) * T
 !
 
     call dmfsdj(A,n,eps,ier)
-      
+
 
 
     if (ier.lt.0) goto 9
@@ -887,7 +895,7 @@
 !     PREPARE INVERSION-LOOP
 !
 !
-! calcul du log du determinant    
+! calcul du log du determinant
 
 !      do i=1,n
 !         det=det+dlog(A(i*(i+1)/2))
@@ -917,25 +925,25 @@
 !
 !     START INNER LOOP
 !
-            do l=lanf,min 
+            do l=lanf,min
                 lver=lver+1
                 lhor=lhor+l
                 work=work+A(lver)*A(lhor)
-            end do        
+            end do
 !
 !     END OF INNER LOOP
 !
             A(j)=-work*din
             j=j-min
         end do
-     
+
 !
 !     END OF ROW-LOOP
 !
-5        ipiv=ipiv-min 
+5        ipiv=ipiv-min
         ind=ind-1
     end do
-      
+
 !
 !     END OF INVERSION-LOOP
 !
@@ -959,15 +967,15 @@
                 lver=lhor+k-i
                 work=work+A(lhor)*A(lver)
                 lhor=lhor+l
-            end do        
+            end do
 !
 !     END OF INNER LOOP
-!       
+!
             A(j)=work
             j=j+k
         end do
     end do
-      
+
 !
 !     END OF ROW-AND MULTIPLICATION-LOOP
 !
@@ -979,18 +987,18 @@
 !------------------------------------------------------------
 
     subroutine valfpaj(vw,fi,b,bk,m,delta,k0,fctnames)
-    
+
     implicit none
-    
-    integer,intent(in)::m  
-    double precision,dimension(m),intent(in)::b,delta  
-    double precision,dimension(m),intent(out)::bk 
-    double precision,intent(out)::fi 
-    double precision::vw,fctnames,z    
+
+    integer,intent(in)::m
+    double precision,dimension(m),intent(in)::b,delta
+    double precision,dimension(m),intent(out)::bk
+    double precision,intent(out)::fi
+    double precision::vw,fctnames,z
     double precision,dimension(2)::k0
     integer::i0,i
     external::fctnames
-    
+
     z=0.d0
     i0=1
     do i=1,m
@@ -1002,21 +1010,21 @@
     end if
 1       continue
     return
-    
+
     end subroutine valfpaj
 
 !------------------------------------------------------------
 !                            MAXT
 !------------------------------------------------------------
     subroutine dmaxt(maxt,delta,m)
-    
+
     implicit none
-    
+
     integer,intent(in)::m
     double precision,dimension(m),intent(in)::delta
     double precision,intent(out)::maxt
-    integer::i 
-    
+    integer::i
+
     maxt=Dabs(delta(1))
 
     do i=2,m
@@ -1024,8 +1032,8 @@
             maxt=Dabs(delta(i))
         end if
 
-    end do 
-        
+    end do
+
     return
     end subroutine dmaxt
 
@@ -1048,9 +1056,9 @@
 
 !add additive
     use additiv,only:correl
-      
+
     IMPLICIT NONE
-!   variables globales 
+!   variables globales
     integer,intent(in) :: m,effet
     integer,intent(inout)::ni,ier,istop
     double precision,dimension(m*(m+3)/2),intent(out)::v
@@ -1059,7 +1067,7 @@
     double precision,intent(out)::ca,cb,dd
     double precision,dimension(3)::k0
         double precision,dimension(3)::zero
-!   variables locales            
+!   variables locales
     integer::nql,ii,nfmax,idpos,ncount,id,jd,m1,j,i,ij,k
     double precision,dimension(m*(m+3)/2)::fu,v1,vnonpen
     double precision,dimension(m)::delta,b1,bh
@@ -1071,16 +1079,16 @@
 !---------- ajout
     integer::kkk
 
-    zero=0.d0     
+    zero=0.d0
     id=0
     jd=0
     z=0.d0
     th=1.d-5
     eps=1.d-7!1.d-6
-    nfmax=m*(m+1)/2        
+    nfmax=m*(m+1)/2
     ca=epsa+1.d0
     cb=epsb+1.d0
-    rl1=-1.d+10    
+    rl1=-1.d+10
     ni=0
     istop=0
     da=0.01d0
@@ -1088,9 +1096,9 @@
     nql=1
     m1=m*(m+1)/2
     ep=1.d-20
-    Main:Do 
+    Main:Do
 
-        call deriva(b,m,v,rl,k0,fctnames)   
+        call deriva(b,m,v,rl,k0,fctnames)
 
         rl1=rl
     if(rl.eq.-1.D9) then
@@ -1098,21 +1106,21 @@
         goto 110
     end if
 !    write(*,*)'parameters***',b
-!     write(*,*)'Optim iteration***',ni,'vrais',rl  
-       
-        dd = 0.d0    
-     
+!     write(*,*)'Optim iteration***',ni,'vrais',rl
+
+        dd = 0.d0
+
         fu=0.D0
-    
+
     do i=1,m
         do j=i,m
             ij=(j-1)*j/2+i
             fu(ij)=v(ij)
         end do
     end do
-    
-        call dsinvj(fu,m,ep,ier)  
-    
+
+        call dsinvj(fu,m,ep,ier)
+
     if (ier.eq.-1) then
         dd=epsd+1.d0
     else
@@ -1129,7 +1137,7 @@
         end do
         dd=GHG/dble(m)
     end if
-    
+
 !    print*,ca,cb,dd
     if(ca.lt.epsa.and.cb.lt.epsb.and.dd.lt.epsd) exit main
 
@@ -1139,14 +1147,14 @@
             tr=tr+dabs(v(ii))
         end do
         tr=tr/dble(m)
-        
+
         ncount=0
         ga=0.01d0
-        
+
  400    do i=1,nfmax+m
            fu(i)=v(i)
         end do
-    
+
         do i=1,m
             ii=i*(i+1)/2
             if (v(ii).ne.0) then
@@ -1155,7 +1163,7 @@
                 fu(ii)=da*ga*tr
             endif
         end do
-        
+
         call dcholej(fu,m,nql,idpos)
         if (idpos.ne.0) then
             ncount=ncount+1
@@ -1165,7 +1173,7 @@
                 ga=ga*dm
                 if (ga.gt.1.d0) ga=1.d0
             endif
-    
+
             goto 400
 
         else
@@ -1195,7 +1203,7 @@
         else
             !call dmaxt(maxt,delta,m)
             vw=th/maxt
-            
+
         endif
         step=dlog(1.5d0)
 !      write(*,*) 'searpas'
@@ -1205,7 +1213,7 @@
             istop=4
             goto 110
         end if
-            
+
         do i=1,m
             delta(i)=vw*delta(i)
         end do
@@ -1220,22 +1228,22 @@
         do i=1,m
             b(i)=b(i)+delta(i)
         end do
-    
+
         ni=ni+1
 
         if (ni.ge.maxiter) then
             istop=2
  !           write(6,*) 'maximum number of iteration reached'
             goto 110
-        end if     
+        end if
     End do Main
 
     v=0.D0
-        
+
     v(1:m*(m+1)/2)=fu(1:m*(m+1)/2)
-    
+
     istop=1
-    
+
 !================ pour les bandes de confiance
 !==== on ne retient que les para des splines
 
@@ -1250,19 +1258,23 @@
     end do
 !---- Choix du model
 
-    select case(model) 
-        case(1)  
+    select case(model)
+        case(1)
             m1=m-nva-effet-indic_alpha !joint
+
+        !cas supplementaire rajout pour joint general
+        case(5)
+            m1=m-nva-effet-indic_alpha !joint general
         case(2)
-            m1=m-nva-effet*2 !additive    
+            m1=m-nva-effet*2 !additive
         case(3)
             m1=m-nva-effet !nested
-        case(4)    
+        case(4)
             m1=m-nva-effet !shared
     end select
 
     kkk=m1*(m1+1)/2
-    
+
     do i=1,m1
         kkk=kkk+1
         do j=i,m1
@@ -1270,11 +1282,11 @@
             v1(k)=v(k)/(4.d0*b(i)*b(j))
         end do
         v1(kkk)=v1(kkk)+(v(kkk)/(4.d0*b(i)*b(i)*b(i)))
-    end do 
+    end do
 
     ep=10.d-10
     call dsinvJ(v1,m1,ep,ier)
-    
+
     if (ier.eq.-1) then
 !         write(*,*)   'echec inversion matrice information'
         istop=3
@@ -1294,13 +1306,13 @@
         end do
     end do
 
-    
+
     ep=10.d-10
     call dsinvJ(v,m,ep,ier)
-    
+
     if (ier.eq.-1) then
         istop=3
-        
+
 !AD:
 !        call dsinvj(v1,m1,ep,ier)
 !        if (ier.eq.-1) then
@@ -1311,20 +1323,20 @@
 !            DO k=1,m1*(m1+1)/2
 !                v(k)=v1(k)
 !            END DO
-!        end if    
+!        end if
 ! fin ajout amadou
     endif
 
-    
+
     ep=10.d-10
     call deriva(b,m,vnonpen,rl,zero,fctnames)
-    
+
     do i=1,m
         do j=i,m
             I_hess(i,j)=vnonpen((j-1)*j/2+i)
         end do
     end do
-   
+
     do i=2,m
         do j=1,i-1
             I_hess(i,j)=I_hess(j,i)
@@ -1345,7 +1357,7 @@
         do j=1,i-1
             H_hess(i,j)=H_hess(j,i)
         end do
-    end do      
+    end do
 
  !AD:
     if (typeof .ne. 0) then
@@ -1356,7 +1368,7 @@
 
  110   continue
 
-       return    
+       return
 
        end subroutine marq98
 
@@ -1364,28 +1376,30 @@
     subroutine deriva(b,m,v,rl,k0,fctnames)
     use comonmultiv,only:model
     implicit none
-    
+
     integer,intent(in)::m
     double precision,intent(inout)::rl
     double precision,dimension(3)::k0
     double precision,dimension(m),intent(in)::b
-    double precision,dimension((m*(m+3)/2)),intent(out)::v     
+    double precision,dimension((m*(m+3)/2)),intent(out)::v
     double precision,dimension(m)::fcith
     integer ::i0,m1,ll,i,k,j,iun
-    double precision::fctnames,thn,th,z,vl,th2,vaux  
+    double precision::fctnames,thn,th,z,vl,th2,vaux
     external::fctnames
-          
+
     select case(model)
     case(1)
-        th=1.d-3 !joint    
+        th=1.d-3 !joint
+    case(5)
+        th=1.d-5 !joint general
     case(2)
         th=5.d-3 !additive
     case(3)
-        th=1.d-5 !nested        
+        th=1.d-5 !nested
     case(4)
         th=1.d-5 !shared
     end select
-    
+
     thn=-th
     th2=th*th
     z=0.d0
@@ -1396,7 +1410,7 @@
         if(rl.eq.-1.d9) then
             rl=-1.d9
             goto 123
-        end if    
+        end if
     do i=1,m
         fcith(i)=fctnames(b,m,i,th,i0,z,k0)
                 if(fcith(i).eq.-1.d9) then
@@ -1408,14 +1422,14 @@
     k=0
     m1=m*(m+1)/2
     ll=m1
-    
+
     do i=1,m
         ll=ll+1
         vaux=fctnames(b,m,i,thn,i0,z,k0)
                 if(vaux.eq.-1.d9) then
                     rl=-1.d9
                     goto 123
-                end if    
+                end if
         vl=(fcith(i)-vaux)/(2.d0*th)
         v(ll)=vl
         do j=1,i
@@ -1423,10 +1437,10 @@
             v(k)=-(fctnames(b,m,i,th,j,th,k0)-fcith(j)-fcith(i)+rl)/th2
         end do
     end do
-      
-123   continue    
+
+123   continue
     return
-    
+
     end subroutine deriva
 
 
@@ -1435,22 +1449,22 @@
 !  MINIMISATION UNIDIMENSIONNELLE
 !
       implicit none
-       
-      integer,intent(in)::m      
+
+      integer,intent(in)::m
       double precision,dimension(m),intent(in)::b
       double precision,intent(inout)::vw
-      double precision,dimension(m),intent(inout)::bh,delta      
-      double precision,intent(inout)::fim,step   
-      double precision::vlw,vlw1,vlw2,vlw3,vm,fi1,fi2,fi3    
+      double precision,dimension(m),intent(inout)::bh,delta
+      double precision,intent(inout)::fim,step
+      double precision::vlw,vlw1,vlw2,vlw3,vm,fi1,fi2,fi3
       double precision,dimension(3)::k0
       double precision::fctnames
       external::fctnames
-      integer::i 
+      integer::i
 
        vlw1=dlog(vw)
        vlw2=vlw1+step
        call valfpa(vlw1,fi1,b,bh,m,delta,k0,fctnames)
-       call valfpa(vlw2,fi2,b,bh,m,delta,k0,fctnames)       
+       call valfpa(vlw2,fi2,b,bh,m,delta,k0,fctnames)
 
        if(fi2.ge.fi1) then
       vlw3=vlw2
@@ -1460,9 +1474,9 @@
       step=-step
 
           vlw1=vlw2+step
-          call valfpa(vlw1,fi1,b,bh,m,delta,k0,fctnames)   
+          call valfpa(vlw1,fi1,b,bh,m,delta,k0,fctnames)
           if(fi1.gt.fi2) goto 50
-       else 
+       else
           vlw=vlw1
           vlw1=vlw2
           vlw2=vlw
@@ -1482,7 +1496,7 @@
           if(fi1.gt.fi2) goto 50
           if(fi1.eq.fi2) then
              fim=fi2
-             vm=vlw2 
+             vm=vlw2
              goto 100
           end if
        end do
@@ -1493,32 +1507,32 @@
 !
 !  CALCUL MINIMUM QUADRIQUE
 !
-      vm=vlw2-step*(fi1-fi3)/(2.d0*(fi1-2.d0*fi2+fi3))   
-      call valfpa(vm,fim,b,bh,m,delta,k0,fctnames)    
+      vm=vlw2-step*(fi1-fi3)/(2.d0*(fi1-2.d0*fi2+fi3))
+      call valfpa(vm,fim,b,bh,m,delta,k0,fctnames)
       if(fim.le.fi2) goto 100
       vm=vlw2
       fim=fi2
 100   continue
       vw=dexp(vm)
-      
+
       return
 
       end subroutine searpas
 
 
     subroutine valfpa(vw,fi,b,bk,m,delta,k0,fctnames)
-    
+
     implicit none
-    
-    integer,intent(in)::m  
-    double precision,dimension(m),intent(in)::b,delta  
-    double precision,dimension(m),intent(out)::bk 
-    double precision,intent(out)::fi 
-    double precision::vw,fctnames,z    
+
+    integer,intent(in)::m
+    double precision,dimension(m),intent(in)::b,delta
+    double precision,dimension(m),intent(out)::bk
+    double precision,intent(out)::fi
+    double precision::vw,fctnames,z
     double precision,dimension(3)::k0
     integer::i0,i
     external::fctnames
-    
+
     z=0.d0
     i0=1
     do i=1,m
@@ -1530,16 +1544,11 @@
     end if
 1       continue
     return
-    
+
     end subroutine valfpa
 
 
 
-
-
-
-
-
     end module optim
 
-        
+
